pub struct Zec<C: Constraint>(Amount<C>);Expand description
A wrapper type that formats Amounts as ZEC, using double-precision floating point.
This formatting is accurate to the nearest zatoshi, as long as the number of floating-point
calculations is very small. This is because MAX_MONEY uses 51 bits, but f64 has
53 bits of precision.
Rust uses roundTiesToEven, which can lose one bit of precision per calculation
in the worst case. (Assuming the platform implements it correctly.)
Unlike zcashd, Zebra doesn’t have control over its JSON number precision,
because it uses serde_json’s formatter. But zcashd uses a fixed-point calculation:
https://github.com/zcash/zcash/blob/f6a4f68115ea4c58d55c8538579d0877ba9c8f79/src/rpc/server.cpp#L134
Tuple Fields
0: Amount<C>Implementations